@@ -96,3 +96,9 @@ class ManySerialiserField(Field):
     def restore(self, value, **kwargs):
         return self.serialiser.list_inflate(value, **kwargs)
 
+
+class FileField(Field):
+    def reduce(self, value, **kwargs):
+        return value.url
+    def restore(self, value, **kwargs):
+        pass
